PlotLR: Ligand-Receptor plotting - mean of mean expressions

Description Usage Arguments Value

View source: R/PlotLR.R

Description

Ligand-Receptor plotting - mean of mean expressions

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
PlotLR(
  results,
  ligands = NULL,
  receptors = NULL,
  l.cells = NULL,
  r.cells = NULL,
  split.subset = NULL,
  split.along.y = FALSE,
  use.adj.pval = FALSE,
  pval.threshold = 0.05,
  min.exp.percent = 0.1,
  min.cell.percent = 0,
  resample = 1000
)

Arguments

results

data.frame containing output from StandardLR.

ligands

Character vector with specific ligands of interest to plot. If NULL, all available ligand genes will be plotted.

receptors

Character vector with sepcific receptors of interest to plot. If NULL, all available receptor genes will be plotted.

l.cells

Character vector with specific cell clusters to plot as the ligand-expressing cell-type. If NULL, all available cell cluster types will be plotted.

r.cells

Character vector with specific cell clusters to plot as the receptor-expressing cell-type. If NULL, all available cell cluster types will be plotted.

split.subset

Character vector with values of split.by column from results to retain. All other values will be removed from plotting. If NULL, all available values of split.by will be plotted.

split.along.y

Logical whether split.by plot facets should run horizontally (FALSE) or vertically (TRUE).

use.adj.pval

Logical whether to plot adjusted p-values column from results. Default is FALSE.

pval.threshold

Numeric value of the maximum p-value or adjusted p-value to plot. All scores with p-values greater than the threshold will be removed.

min.exp.percent

Numeric value of the minimum percent that a cell cluster must express a gene in order to be plotted. Percent expresses below this value will not be plotted.

min.cell.percent

Numeric value (need to expand more).

resample

Numeric value of the number of resamplings used in the permutation test.

Value

A ggplot2 object with the ligand-receptor plot.


JamesChoi94/SingleCellTools documentation built on April 5, 2021, 9:27 p.m.