Description Usage Arguments Value
Ligand-Receptor scoring - mean of mean expressions
1 2 3 4 5 6 7 8 9 10 11 |
object |
Seurat object containing RNA expression data. |
ref.path |
Character string of path to ligand-receptor pair reference
list. LR pair reference must contain a column labeled "Pair.Name" with values
for each LR pair. If |
lr.ref |
Data.frame of ligand-receptor pair reference. Must contain a
column labeled "Pair.Name" with values for each LR pair. If |
split.by |
Character string of a column name in
|
min.pct |
Numeric minimum percentage a ligand or receptor gene must be
expressed in any cell cluster to be retained for LR scoring. Note: scores
will still be calculated between pairs where one cluster expresses at 15% and
the other at 0%. These scores should be filtered out at visualization
(see: |
assay |
Character string to select which assay slot of Seurat object to use. |
resample |
Numeric number of times to sample cells for permutation test. |
adjust.pval |
Logical determining whether to perform max-T p-value adjustment. |
A data.frame containing results of the standard ligand-receptor analysis. The columns of the data.frame as as follow:
'Pair_name' : Name of ligand gene followed and separated by name of receptor gene.
'Score' : Average of mean ligand expression in ligand cluster and mean receptor expression in receptor cluster.
'pval' : Estimated p-value using a permutation test. See description for more method details.
'adj_pval' : Adjusted p-value using a max-T adjustment. See https://statistics.berkeley.edu/sites/default/files/tech-reports/633.pdf equation 11 for more details.
'Ligand_cell' : Ligand-expressing cell cluster.
'Receptor_cell' : Receptor-expressing cell cluster.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.