StandardLR2: Ligand-Receptor scoring - mean of mean expressions

Description Usage Arguments Value

View source: R/StandardLR2.R

Description

Ligand-Receptor scoring - mean of mean expressions

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
StandardLR2(
  seurat.object,
  ref.path = NULL,
  lr.ref = NULL,
  split.by = NULL,
  min.pct = 0.1,
  assay = "RNA",
  slot = "data",
  resample = 1000,
  adjust.pval = FALSE,
  BPPARAM = bpparam()
)

Arguments

seurat.object

Seurat object containing RNA expression data.

ref.path

Character string of path to ligand-receptor pair reference list. LR pair reference must contain a column labeled "Pair.Name" with values for each LR pair. If NULL, lr.ref must be provided.

lr.ref

Data.frame of ligand-receptor pair reference. Must contain a column labeled "Pair.Name" with values for each LR pair. If NULL, ref.path must be provided.

split.by

Character string of a column name in slot(tmp,'meta.data') by which to split cells before calculating LR scores e.g. across multiple conditions or time-points.

min.pct

Numeric minimum percentage a ligand or receptor gene must be expressed in any cell cluster to be retained for LR scoring. Note: scores will still be calculated between pairs where one cluster expresses at 15% and the other at 0%. These scores should be filtered out at visualization (see: PlotLR).

assay

Character string to select which assay slot of Seurat object to use.

resample

Numeric number of times to sample cells for permutation test.

adjust.pval

Logical determining whether to perform max-T p-value adjustment.

Value

A data.frame containing results of the standard ligand-receptor analysis. The columns of the data.frame as as follow:


JamesChoi94/SingleCellTools documentation built on April 5, 2021, 9:27 p.m.