Description Usage Arguments Value
Ligand-Receptor plotting - mean of mean expressions
1 2 3 4 5 6 7 8 9 10 11 12 13 14 |
results |
data.frame containing output from |
ligands |
Character vector with specific ligands of interest to plot. If
|
receptors |
Character vector with sepcific receptors of interest to
plot. If |
l.cells |
Character vector with specific cell clusters to plot as the
ligand-expressing cell-type. If |
r.cells |
Character vector with specific cell clusters to plot as the
receptor-expressing cell-type. If |
split.subset |
Character vector with values of |
split.along.y |
Logical whether |
use.adj.pval |
Logical whether to plot adjusted p-values column from
|
pval.threshold |
Numeric value of the maximum p-value or adjusted p-value to plot. All scores with p-values greater than the threshold will be removed. |
min.exp.percent |
Numeric value of the minimum percent that a cell cluster must express a gene in order to be plotted. Percent expresses below this value will not be plotted. |
min.cell.percent |
Numeric value (need to expand more). |
resample |
Numeric value of the number of resamplings used in the permutation test. |
A ggplot2 object with the ligand-receptor plot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.